//=============================================================================
// TRP_SkitPatchForInazuma.js
//=============================================================================
/*:
 * @plugindesc イベントCG対応など
 * @author Thirop
 * @help
 * □xy移動(斜め移動)
 * skit xyMove 対象キャラ名 wait x位置(0~10) y位置(0以上で下方向) 所要時間 相対値フラグ イージング
 * 
 * 例1）skit xyMove oka t right -100 30
 * okaを30フレームかけてx位置right、y位置-100まで移動
 *
 * 例2）skit xy oka t 3 100 30 t easeOut
 * okaを30フレームかけてx位置3、y位置100だけeaseOutで相対移動
 * 
 * □ポーズ変化時のクロスフェード
 * 作業工数を節約するため既存のフェードイン・アウトでのポーズ変化を
 * クロスフェード処理に割り当ててます。
 * 従来のフェードイン・アウト方式を用いる場合は
 * 所要時間にマイナスの値を指定してください。
 * 
 * 例1）skit pose oka t pose02 face01 fade 30
 * 30フレームかけてクロスフェード
 * 例2）skit pose oka t pose02 face01 fade -30
 * 30フレームかけてフェードイン・フェードアウト
 * 
 * クロスフェードをデフォルトの方式にする場合は
 * TRP_SkitConfigのポーズモーションの切り替え方法を
 * 「フェードで切り替え」に設定してください。
 * 
 *
 * @param CgSettings
 * @text 　立ち絵キャラクター設定
 * @desc 各行・空行をダブルクリックして立ち絵キャラの設定ができます。
 * @type struct<SkitCg>[]
 * @default ["{\"name\":\"ハロルド\",\"basic\":\"==============================\",\"inputName\":\"ハロ\",\"fileName\":\"halold\",\"displayAdjust\":\"==============================\",\"animationOffsetX\":\"0\",\"animationOffsetY\":\"0\",\"displayX\":\"0\",\"displayY\":\"0\"}"]
 * @parent categoryBasic
 *
 * @param disableFileCheck
 * @text ファイル有無確認無効
 * @desc ファイル有無のチェックはブラウザ版では使用できない＆同期的なチェックで処理が基本的には非推奨です。問題が生じたらONにして無効化してください。
 * @default false
 * @type Boolean
 *
 * @param xyMove
 * @text xyMoveコマンド設定
 * @desc xyMoveコマンドのデフォルト設定
 * @type struct<XyMove>
 *
 * @param crossFadeDuration
 * @text クロスフェード所要時間
 * @desc ポーズ変化時のクロスフェードの所要時間。0の場合は随時設定orTRP_SkitConfigの設定値を使用
 * @default 20
 * @type Number
 *
 */

/*~struct~SkitCg:
 * @param name
 * @text キャラクター名
 * @desc メッセージで表示するキャラクター名
 *
 * @param inputName
 * @text 入力キャラクター名
 * @desc メッセージやプラグインコマンドで入力するキャラクター名の略名。（省略で"キャラクター名"と同じ）
 * 
 * @param fileName
 * @text フォルダ名
 * @desc キャラ毎の画像を保存するフォルダ名(アルファベット推奨、他のキャラと重複不可)
 *
 * @param scenes
 * @text シーン設定
 * @desc シーンごとの設定
 * @type struct<Scene>[]
 * @default []
 */

/*~struct~Scene:
 * @param name
 * @text シーン名
 * @desc シーン名（アルファベット）
 *
 * @param displayOffsetY
 * @text 立ち絵表示Y座標
 * @desc 立ち絵のの垂直方向にずらす量（デフォルト：0）
 * @type number
 * @min -10000
 * @default 0
 *
 * @param animationOffsetX
 * @text アニメーション表示X
 * @desc アニメーション表示の水平方向にずらす量（デフォルト：0）
 * @type number
 * @min -10000
 * @default 0
 *
 * @param animationOffsetY
 * @text アニメーション表示Y
 * @desc アニメーション表示の垂直方向にずらす量（デフォルト：0）
 * @type number
 * @min -10000
 * @default 0
 */

/*~struct~XyMove:
 * @param duration
 * @text 所要時間[デフォ値]
 * @desc 所要時間のデフォルト値。（0以上の整数、初期値20）
 * @default 20
 *
 * @param wait
 * @text ウェイト[デフォ値]
 * @desc 移動コマンドのウェイトのデフォルト値(初期値false)
 * @type boolean
 * @default false
 *
 * @param easeType
 * @text イージングタイプ
 * @desc イージング（変化の緩急）のデフォルト値
 * @type select
 * @option リニア(0)
 * @value 0
 * @option イースイン(1)/徐々に早く
 * @value 1
 * @option イースアウト(2)/徐々に遅く
 * @value 2
 * @option イースインアウト(3)/間を早く
 * @value 3
 * @option イースインキュービック(4)/徐々に早く
 * @value 4
 * @option イースアウトキュービック(5)/徐々に遅く
 * @value 5
 * @option イースインアウトキュービック(6)/間を早く
 * @value 6
 * @option バックイン(1)/徐々に早く
 * @value 7
 * @option バックアウト(2)/徐々に遅く
 * @value 8
 * @option バックインアウト(3)/間を早く
 * @value 9
 * @option イラスティックイン(4)/徐々に早く
 * @value 10
 * @option イラスティックアウト(5)/徐々に遅く
 * @value 11
 * @option イラスティックインアウト(6)/間を早く
 * @value 12
 * @default 3
 */

//============================================================================= 

(function(){
var parameters = PluginManager.parameters('TRP_SkitPatchForInazuma');
var mainParameters = null;
var originalParameters = null;

var _TRP_CORE_setupTRPSkitConfigParametersIfNeeded = TRP_CORE.setupTRPSkitConfigParametersIfNeeded;
TRP_CORE.setupTRPSkitConfigParametersIfNeeded = function(){
	if(this.isSkitParametersInitialized)return;

	_TRP_CORE_setupTRPSkitConfigParametersIfNeeded.call(this);

	mainParameters = TRP_CORE.skitParameters;
	originalParameters = JsonEx.makeDeepCopy(mainParameters);

	this.isSkitParametersInitialized = true;
	parameters = JSON.parse(JSON.stringify(parameters, function(key, value) {
		try {
			return JSON.parse(value);
		} catch (e) {
			try {
				if(value[0]==='['||value[0]==='{'){
					if(value.contains(' ')){
						return value;
					}
					return eval(value);
				}else if(!isNaN(value)){
					return Number(value);
				}else if(value==='true'){
					return true;
				}else if(value==='false'){
					return false;
				}else{
					return value;
				}
			} catch (e) {
				return value;
			}
		}
	}));

	var errorPrefix = 'TRP_SkitPatchForInazuma:';
	try{
		/* setup SkitActorSettings
		===================================*/
		var characterSettingArray = parameters.CgSettings;
		var dataActors = {};
		var names = {};
		parameters.dataActors = dataActors;
		parameters.nameToInputList = names;

		characterSettingArray.forEach(function(character){
			character.inputName = character.inputName || character.name;
			character.fileName = character.fileName || character.inputName;
			if(character.name){
				names[character.name] = character.fileName;
			}
			if(character.inputName){
				names[character.inputName] = character.fileName;
			}
			dataActors[character.fileName] = character;
		});
		delete parameters.CgSettings;
	}catch(e){
		e = new Error(errorPrefix+'CG設定が正しくありません。');
		SceneManager.catchException(e);
	}
};

//=============================================================================
// DataManager
//=============================================================================
var _DataManager_extractSaveContents = DataManager.extractSaveContents;
DataManager.extractSaveContents = function(contents) {
	_DataManager_extractSaveContents.call(this,contents);
	$gameSkit.applySceneSetting();
};



//=============================================================================
// ImageManager
//=============================================================================
var _ImageManager_loadBust = ImageManager.loadBust;
ImageManager.loadBust = function(charaname,filename, hue){
	var scene = $gameSkit.scene();
	if(scene){
		return this.loadCg(charaname,scene,filename,hue);
	}else{
		return _ImageManager_loadBust.call(this,charaname,filename,hue);
	}
};

var _ImageManager_requestBust = ImageManager.requestBust;
ImageManager.requestBust = function(charaname,filename, hue){
	var scene = $gameSkit.scene();
	if(scene){
		return this.requestCg(charaname,scene,filename,hue);
	}else{
		return _ImageManager_requestBust.call(this,charaname,filename,hue);
	}
};


var dirName;
(function(){
	var path = require('path');
    dirName = path.dirname(process.mainModule.filename);
})();

ImageManager.loadCg = function(charaname,sceneName,filename, hue) {
	var dir = 'img/pictures/events/'+charaname+'/'+sceneName+'/';
	if(!parameters.disableFileCheck){
		if(filename.contains('_')){
			var elems = filename.split('_');
			var fs = require('fs');
			try{
				fs.accessSync(dirName+'/'+dir+filename+'.png');
			} catch(err){
				filename = elems[1];
				console.log(filename);
			}
		}
	}
	
	return this.loadBitmap(dir, filename, hue, true);
};
ImageManager.requestCg = function(charaname,sceneName,filename, hue) {
	return this.requestBitmap('img/pictures/events/'+charaname+'/',sceneName+'/', filename, hue, true);
};



//=============================================================================
// Skit
//=============================================================================
var _Skit_clearParameters = Skit.prototype.clearParameters;
Skit.prototype.clearParameters = function(){
	if(this._scene === undefined){
		this._scene = '';
	}else if(this._scene){
		this.changeScene('');
		this.applySceneSetting();
	}
	_Skit_clearParameters.call(this);
};

Skit.prototype.scene = function(){
	return this._scene||'';
};

/* start scene
===================================*/
Skit.prototype.startSkit = function(args,macroPos){
	this.start(args[1]);
};

var _Skit_start = Skit.prototype.start;
Skit.prototype.start = function(scene=''){
	_Skit_start.call(this);
	this.changeScene(scene);
};

var _Skit_prototype_clear = Skit.prototype.clear;
Skit.prototype.clear = function(){
	if(!this._isSkitOn)return;
	_Skit_prototype_clear.call(this);

	this.releaseImageCaches();
};

Skit.prototype.changeScene = function(scene=''){
	this._scene = scene;
	this.applySceneSetting();
};

Skit.prototype.applySceneSetting = function(){
	this._scene = this._scene||'';
	var scene = this._scene;
	if(!scene){
		mainParameters.nameToInputList = originalParameters.nameToInputList;
		mainParameters.dataActors = originalParameters.dataActors;
		mainParameters.bustsScale = originalParameters.bustsScale;
		mainParameters.baseOffsetY = originalParameters.baseOffsetY;
		mainParameters.zOrder = originalParameters.zOrder;
	}else{
		mainParameters.bustsScale = 100;
		mainParameters.baseOffsetY = 0;
		mainParameters.zOrder = 1;

		mainParameters.dataActors = {};
		mainParameters.nameToInputList = [];
		var actors = parameters.dataActors;
		var keys = Object.keys(actors);
		var length = keys.length;
	    for(var i = 0; i<length; i=(i+1)|0){
	        var actor = actors[keys[i]];
	        var scenes = actor.scenes;
	        var sceneLen = scenes.length;
		    for(var j = 0; j<sceneLen; j=(j+1)|0){
		        if(scenes[j].name===scene){
		        	mainParameters.dataActors[actor.fileName] = actor;
		        	if(actor.name){
		        		mainParameters.nameToInputList[actor.name] = actor.fileName;
		        	}
		        	if(actor.inputName){
		        		mainParameters.nameToInputList[actor.inputName] = actor.fileName
		        	}
		        	break;
		        }
	        }
	    }
	}

	this.restoreBustPictureContainerZOrder();
};

Skit.prototype.restoreBustPictureContainerZOrder = function(){
	var sprset = SceneManager._scene._spriteset;
	if(!sprset)return;

	var bustContainer = sprset._bustPictureContainer;
	var pictContainer = sprset._pictureContainer;
	if(!bustContainer)return;

	var index = sprset.children.indexOf(pictContainer);
	if(mainParameters.zOrder===0){
		SceneManager._scene.addChild(bustContainer);
	}else if(mainParameters.zOrder===1){
		sprset.addChildAt(bustContainer,index+1);
	}else{
		sprset.addChildAt(bustContainer,index);
	}
};


/* cache
===================================*/
Skit.prototype.releaseImageCaches = function(){
	var items = ImageManager._imageCache._items;
	var keys = Object.keys(items);
	var length = keys.length;

	var regexp = /^img\/pictures\/bust|^img\/pictures\/events/;
    for(var i = 0; i<length; i=(i+1)|0){
        if(regexp.test(keys[i])){
        	delete items[keys[i]];
        }
    }
};




/* command
===================================*/
var _Skit_processCommand = Skit.prototype._processCommand;
Skit.prototype._processCommand = function(args,macroPos){
	var skitCommand = args[0].toLowerCase();

	switch(skitCommand){
	case 'xy':
	case 'xymove':
	case 'xy移動':
	case '斜め移動':
		this.moveXySkitActor(args,macroPos);
		break;
	default:
		_Skit_processCommand.call(this,args,macroPos);
	}
};


/* move xy
 *  [1] : name
 *  [2] : wait
 *  [3] : xPosition
 *  [4] : yPosition
 *  [5] : duration
 *  [6] : relative(false)
 *  [7] : easeType
===================================*/
Skit.prototype.moveXySkitActor = function(args,macroPos){
	var wait = args[2];
	var xPosition = TRP_CORE.supplementDef(args[3],macroPos);
	var yPosition = TRP_CORE.supplementDef(0,args[4]);
	var duration = args[5];
	var relative = args[6];
	var easeType = args[7];


	var targetActors = this.targetActors(args[1]);
	var length = targetActors.length;
    for(var i = 0; i<length; i=(i+1)|0){
        var actor = targetActors[i];
        if(actor){
        	actor.moveXyPosition(wait,easeType,xPosition,yPosition,duration,relative);
		}
		wait = false;
	}
};


//=============================================================================
// SkitActor
//=============================================================================
var _SkitActor_data = SkitActor.prototype.data;
SkitActor.prototype.data = function(){
	var scene = $gameSkit.scene()
	if(!scene){
		return _SkitActor_data.call(this);
	}else{
		var scenes = mainParameters.dataActors[this._name].scenes;
		var length = scenes.length;
	    for(var i = 0; i<length; i=(i+1)|0){
	        if(scenes[i].name === scene){
	        	return scenes[i];
	        }
	    }
	}
	return {};
};



/* move xy position
===================================*/
SkitActor.prototype.moveXyPosition = function(wait,easeType,xPosition,yPosition,duration,relative){
	var defParams = parameters.xyMove;
	wait = TRP_CORE.supplementSkitWait(defParams?defParams.wait:true, wait);
	easeType = TRP_CORE.supplementEasingArg(defParams?defParams.easeType:TRP_CORE.EASING.easeOutQuad, easeType);
	xPosition = TRP_CORE.interpretPositionArg(xPosition);
	yPosition = TRP_CORE.interpretPositionArg(yPosition);
	duration = TRP_CORE.supplementSpeedArg(defParams?defParams.duration:20,duration);
	relative = TRP_CORE.supplementDefBool(false,relative);

	this._offsetY = yPosition + (relative ? this._offsetY : this.data().displayOffsetY);
	this.movePositionDur(wait,easeType,xPosition,duration,relative);
}


/* cross fade
===================================*/
var _SkitActor_changeImageWithFadeAnimation = SkitActor.prototype.changeImageWithFadeAnimation;
SkitActor.prototype.changeImageWithFadeAnimation = function(wait,easeType,duration){
	wait = TRP_CORE.supplement(false,wait);

	if(duration<=0){
		duration *= -1;
		_SkitActor_changeImageWithFadeAnimation.call(this,wait,easeType,duration);
		return;
	}else{
		this.changeImageWithCrossFadeAnimation(wait,easeType,duration);
	}
};

SkitActor.prototype.changeImageWithCrossFadeAnimation = function(wait,easeType,duration){
	wait = TRP_CORE.supplement(false,wait);
	if(Number(parameters.crossFadeDuration)>0){
		var lastDuration = duration;
		duration = Number(parameters.crossFadeDuration);
	}

	if(wait){
		this.wait(duration);
	}

	var opacity = this._opacity;

	var imageName = this.fileName();
	var picture = this.picture();
	picture.changeImage(imageName);
	picture.startCrossFade(duration);

	picture.changeOverlay(this.overlayName(),duration);
};


//=============================================================================
// Game_Picture
//=============================================================================
var _Game_Picture_initialize = Game_Picture.prototype.initialize;
Game_Picture.prototype.initialize = function(){
	_Game_Picture_initialize.call(this);
	this._crossFadeDuration = 0;
};

Game_Picture.prototype.startCrossFade = function(duration){
	this._crossFadeDuration = duration||Number(parameters.crossFadeDuration)||20;
};
Game_Picture.prototype.clearCrossFade = function(){
	this._crossFadeDuration = 0;
};


//=============================================================================
// Sprite_Picture
//=============================================================================
var _Sprite_Picture_initialize = Sprite_Picture.prototype.initialize;
Sprite_Picture.prototype.initialize = function(pictureId){
	_Sprite_Picture_initialize.call(this,pictureId);

	this._crossFadeOverlay = null;
	this._crossFadeDuration = 0;
};

var _Sprite_Picture_didLoadPoseImage = Sprite_Picture.prototype.didLoadPoseImage;
Sprite_Picture.prototype.didLoadPoseImage = function(pictureName,bitmap){
	var picture = this.picture();
	var needsCrossFade = this._isBustPicture && this._pictureName===pictureName && picture && picture._crossFadeDuration;
	if(needsCrossFade){		
		this.crossFadeOut(picture._crossFadeDuration);
	}

	_Sprite_Picture_didLoadPoseImage.call(this,pictureName,bitmap);

	if(needsCrossFade){		
		this.crossFadeIn(picture._crossFadeDuration);
		picture.clearCrossFade();
	}
};

Sprite_Picture.prototype.crossFadeOut = function(duration){
	//fadeout overlay
	var dummyOverlayName = this._pictureName + '_' + 'crossFadeOut';

	this._crossFadeDuration = duration;

	var overlay = this._overlay;
	if(overlay && !overlay._overlayName.contains(this._pictureName+'_')){
		overlay._overlayName = dummyOverlayName;

		overlay._fadeOutDuration = duration;
		overlay._fadeInDuration = 0;
		overlay._fadeSpeed = -overlay.opacity/duration;

		this._overlay = null;
	}


	//fadeout old pose
	if(this.bitmap){
		var sprite = new Sprite(this.bitmap);
		sprite.anchor.set(this.anchor.x,0);
		sprite.setFrame(this._frame.x,this._frame.y,this._frame.width,this._frame.height);
		sprite.rotation = this.rotation;
		sprite.opacity = this.opacity;

		sprite._fadeOutDuration = duration;
		sprite._fadeInDuration = 0;
		sprite._fadeSpeed = -sprite.opacity/duration;

		sprite._overlayName = dummyOverlayName;

		this._overlays.push(sprite);
		this.addChildAt(sprite,0);
	}
};

Sprite_Picture.prototype.crossFadeIn = function(duration){
	//fadein new pose
	if(this.bitmap){
		var sprite = new Sprite(this.bitmap);
		sprite.anchor.set(this.anchor.x,this.anchor.y);
		sprite.setFrame(this._frame.x,this._frame.y,this._frame.width,this._frame.height);
		sprite.rotation = this.rotation;
		var opacity = this.opacity;
		sprite.opacity = 0;

		sprite._fadeSpeed = opacity/duration;
		sprite._fadeOutDuration = 0;
		sprite._fadeInDuration = duration;

		this._overlays.push(sprite);
		this.addChild(sprite);

		sprite._overlayName = this._pictureName+'_crossFadeIn'

		this._crossFadeOverlay = sprite;
		this.bitmap = null;
	}

	if(this._overlay){
		this.addChild(this._overlay);
		this._overlay.opacity = 0;
		this._overlay._fadeSpeed = 255/duration;
		this._overlay._fadeInDuration = duration;
		this._overlay._fadeOutDuration = 0;
	}
};


var _Sprite_Picture_updateOverlay = Sprite_Picture.prototype.updateOverlay;
Sprite_Picture.prototype.updateOverlay = function(){
	_Sprite_Picture_updateOverlay.call(this);

	if(this._crossFadeOverlay){
		if(!this._crossFadeOverlay.parent){
			this._crossFadeOverlay = null;
		}else if(this._crossFadeOverlay._fadeInDuration<=0){
			this.bitmap = this._crossFadeOverlay.bitmap;
			this.removeOverlay(this._crossFadeOverlay);
			this._crossFadeOverlay = null;

			var overlays = this._overlays;
			var length = overlays.length;
		    for(var i = length-1; i>=0; i=(i-1)|0){
		        var overlay = overlays[i];
		        if(overlay._overlayName.contains('_crossFadeOut')){
		        	this.removeOverlay(overlay);
		        }
		    }
		}
	}
};




var _Sprite_Picture_loadBitmap = Sprite_Picture.prototype.loadBitmap;
Sprite_Picture.prototype.loadBitmap = function() {
	_Sprite_Picture_loadBitmap.call(this);

	if(this.isBustPicture() && this._crossFadeOverlay){
		this.bitmap = null;
	}
};

Sprite_Picture.prototype.setOverlayPosition = function(){
	if(!this._crossFadeOverlay && 
		(!this.bitmap || !this.bitmap.isReady()))
	{
		return;
	}
	
	var overlays = this._overlays;
	var length = overlays.length;
	for(var i = 0; i<length; i=(i+1)|0){
		var overlay = overlays[i];
		if(!overlay)continue;

		if(overlay._overlayName.indexOf(this._pictureName)!==0)continue;
		if(!overlay.bitmap.isReady())continue;
		if(overlay._overlayName.contains('crossFadeIn'))continue;

		var target = this._crossFadeOverlay ? this._crossFadeOverlay : this;
		overlay.y = -target.bitmap.height*target.anchor.y;
		overlay.visible = true;


		if(overlay._overlayName.indexOf('_crossFadeOut')<0){
			this.addChild(overlay);
		}
	}
};

})();